@@ -2,8 +2,9 @@ package DBIx::Class::HTMLWidget;
 use strict;
 use warnings;
 use Carp;
+use Data::Dump qw(dump);
 
-our $VERSION = '0.09';
+our $VERSION = '0.13';
 # pod after __END__
 
 sub fill_widget {
@@ -16,6 +17,7 @@ sub fill_widget {
     foreach my $element ( @real_elements ) {
         my $name=$element->name;
         next unless $name && $dbic->can($name) && $element->can('value');
+        next if ($element->value());
         if($element->isa('HTML::Widget::Element::Checkbox')) {
 			  $element->checked($dbic->$name?1:0);
 		  } else {
@@ -45,12 +47,20 @@ sub populate_from_widget {
         if ($col_info->{data_type} and $col_info->{data_type} =~ m/^timestamp|date|integer|numeric/i 
             and defined $value and $value eq '') {
             $value = undef;
+            $dbic->$col(undef);
         }
 
         if (defined($value) and !ref($value) and $value eq 'undef') {
+            $dbic->$col(undef);
             $value = undef;
         }
-        
+        if ($col_info->{data_type} and $col_info->{data_type} =~ m/boolean/i
+            && exists $col_info->{is_nullable} && !$col_info->{is_nullable}
+            && exists $cb{$col} && !defined($value) 
+            && $dbic->result_source->schema->storage->sqlt_type eq 'PostgreSQL') {
+            # We need to set the value to 0 if it is postgres
+            $value = 0;
+        }
         $dbic->$col($value)
             if defined $value || exists $cb{$col};
     }
@@ -167,6 +177,17 @@ Fill the values of a widgets elements with the values of the DBIC object.
 
 Create or update a DBIx::Class row from a HTML::Widget::Result object
 
+=head1 CAEVATS / POSSIBLE PROBLEMS
+
+=head2 PostgreSQL
+
+=head3 ERROR:  null value in column "private" violates not-null constraint
+
+This is a result of we trying to set a value to undef that should not be. This is typicaly
+a problem when you have a colum such ass "private boolean not null". We have a special-case
+for this, and if you set data_type => boolean, is_nullable => 0 in your ResultSource definition,
+we update the value to 0 before attempting to insert or update
+
 =head1 AUTHORS
 
 Thomas Klausner, <domm@cpan.org>, http://domm.zsi.at
